#include <bits/stdc++.h>

using namespace std;

struct Seg {
    int l, r, ind;
};

bool cmp(const Seg& a, const Seg& b) {
    if (a.r != b.r) return a.r < b.r;
    return a.l > b.l;
}

struct SegmentTree {
    int n;
    vector <pair <int, int>> t;

    SegmentTree(int n, vector <Seg>& a) : n(n) {
        t.resize(4 * n);
        build(1, 0, n - 1, a);
    }

    void build(int v, int l, int r, vector <Seg>& a) {
        if (l == r) {
            t[v].first = a[l].l;
            t[v].second = l;
            return;
        }
        int m = (l + r) / 2;
        build(2 * v, l, m, a);
        build(2 * v + 1, m + 1, r, a);
        t[v] = max(t[2 * v], t[2 * v + 1]);
    }

    pair <int, int> get_max(int v, int l, int r, int A, int B) {
        if (l > B || A > r) return make_pair(-1, 0);
        if (A <= l && r <= B) return t[v];
        int m = (l + r) / 2;
        return max(get_max(2 * v, l, m, A, B), get_max(2 * v + 1, m + 1, r, A, B));
    }

    inline pair <int, int> get_max(int l, int r) {
        return get_max(1, 0, n - 1, l, r);
    }

    void update(int v, int l, int r, int i) {
        if (l > i || i > r) return;
        if (l == r) {
            t[v].first = -1;
            return;
        }
        int m = (l + r) / 2;
        update(2 * v, l, m, i);
        update(2 * v + 1, m + 1, r, i);
        t[v] = max(t[2 * v], t[2 * v + 1]);
    }

    inline void update(int i) {
        update(1, 0, n - 1, i);
    }
};

const int INF = 1e9 + 10;

inline void solve() {
    int n;
    cin >> n;
    vector <Seg> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i].l >> a[i].r;
        a[i].ind = i;
    }
    sort(a.begin(), a.end(), cmp);
    vector <int> opt(n), removed(n), cnt(n);
    vector <vector <int>> flex(n);
    set <pair <int, int>> s;
    set <int> current;
    int cur = -1, rs = 0;
    SegmentTree t(n, a);
    for (int i = 0; i < n; ++i) {
        if (a[i].l > cur) {
            cur = a[i].r;
            opt[i] = 1;
            rs++;
            t.update(i);
            current.insert(i);
        }
    }

    auto relax_segment = [&](int i) {
        auto it = current.lower_bound(i);
        int prv_r = -1, nxt_r = n;
        if (it != current.begin()) prv_r = a[*prev(it)].r;
        it++;
        if (it != current.end()) nxt_r = *it;
        s.erase(make_pair(cnt[i], i));
        while (true) {
            pair <int, int> mx = t.get_max(i + 1, nxt_r - 1);
            if (mx.first > prv_r) {
                ++cnt[i];
                t.update(mx.second);
                flex[i].push_back(mx.second);
            } else {
                break;
            }
        }
        s.insert(make_pair(cnt[i], i));
    };

    for (int i = 0; i < n; ++i) {
        if (!opt[i]) continue;
        relax_segment(i);
    }
    for (int _ = 0; _ < rs / 2; ++_) {
        pair <int, int> to_rem = *s.begin();
        int ps = to_rem.second;
        removed[ps] = 1;
        for (int i : flex[ps]) removed[i] = 1;
        s.erase(s.begin());
        current.erase(ps);
        auto it = current.lower_bound(ps);
        if (it != current.end()) relax_segment(*it);
        if (it != current.begin()) relax_segment(*prev(it));
    }
    int cnt_removed = 0;
    for (int i : removed) cnt_removed += i;
    for (int i = 0; i < n && cnt_removed < n / 2; ++i) {
        if (!opt[i] && !removed[i]) {
            removed[i] = 1;
            ++cnt_removed;
        }
    }
    for (int i = 0; i < n; ++i) {
        if (!removed[i]) cout << i + 1 << " ";
    }
    cout << "\n";
}

int main() {
    if (1) {
        ios_base::sync_with_stdio(false);
        cin.tie(nullptr);
    }
    if (1) {
        int t;
        cin >> t;
        while (t--) {
            solve();
        }
    }
    return 0;
}
