#include <iostream>
#include <vector>
#include <unordered_set>
#include <algorithm>
#include <set>

using namespace std;
typedef long long ll;
typedef pair<ll, ll> pll;
typedef pair<pll, ll> segment;
ll t, n;
vector<ll> collisions_count;

const ll DELETE = -1;
const ll ADD = 1;

struct Event {
    ll coord, type, segmentNumber;

    Event(ll coord, ll type, ll segmentNumber) : coord(coord), type(type), segmentNumber(segmentNumber) {};

    Event() : coord(0), type(0), segmentNumber(0) {};
};

bool cmpEvent(Event &e1, Event &e2) {
    return e1.coord < e2.coord || (e1.coord == e2.coord && e1.type == DELETE && e2.type == ADD);
}

bool cmpSegments(pll &s1, pll &s2) {
    return s1.second < s2.second || (s1.second == s2.second && s1.first < s2.first);
}

bool cmpToRemove(segment &s1, segment &s2) {
    return collisions_count[s1.second] < collisions_count[s2.second];
}

int main() {
    cin >> t;
    for (ll tn = 0; tn < t; ++tn) {
        cin >> n;
        vector<segment> segments(n);
        vector<Event> events(n * 2);
        collisions_count.resize(n, 0);
        // для каждого отрезка считаем количество пересечений с помощью сканирующей прямой
        for (ll i = 0; i < n; ++i) {
            collisions_count[i] = 0;
            ll l, r;
            cin >> l >> r;
            segments[i] = {{l, r}, i};
            Event openEvent(l, ADD, i);
            Event closeEvent(r, DELETE, i);
            events[i * 2] = openEvent;
            events[i * 2 + 1] = closeEvent;
        }
        sort(events.begin(), events.end(), cmpEvent);
        unordered_set<ll> opened;
        for (auto event: events) {
            ll coord = event.coord, type = event.type, segmentNumber = event.segmentNumber;
            if (type == ADD) {
                // когда отрезок открылся, мы добавляем ему в пересечение все остальные отрезки, а его - всем остальным отрезкам
                collisions_count[segmentNumber] += opened.size();
                for (auto seg: opened) {
                    collisions_count[seg] += 1;
                }
                opened.insert(segmentNumber);
            } else if (type == DELETE) {
                // когда отрезок закылся, мы просто удаляем его из открытых
                opened.erase(segmentNumber);
            }
        }
        // ----
        // т. к. нам нужно будет удалять отрезки, формируем множество
        // чтобы иметь правильную сортировку, меняем левую и правую границу местами
        set<segment> segments_set;
        for (auto item: segments) {
            segments_set.insert({{item.first.second, item.first.first}, item.second});
        }
        // ищем цепочку
        auto segmentPointer = segments_set.begin();
        set<segment> included;
        included.insert(*(segments_set.begin()));
        ll lastIncludedCoord = (*(segments_set.begin())).first.first;
        ++segmentPointer;

        while (segmentPointer != segments_set.end()) {
            auto testedSegment = *segmentPointer;
            ll l = testedSegment.first.second;
            ll r = testedSegment.first.first;
            if (l > lastIncludedCoord) {
                // мы можем взять этот отрезок
                included.insert(testedSegment);
                lastIncludedCoord = r;
            }
            ++segmentPointer;
        }

        ll m = included.size();
        ll a = m / 2;

        // удаляем неподходящие отрезки
        while (true) {
            auto segmentPointer = segments_set.begin();
            set<segment> included;
            included.insert(*(segments_set.begin()));
            ll lastIncludedCoord = (*(segments_set.begin())).first.first;
            ++segmentPointer;

            while (segmentPointer != segments_set.end()) {
                auto testedSegment = *segmentPointer;
                ll l = testedSegment.first.second;
                ll r = testedSegment.first.first;
                if (l > lastIncludedCoord) {
                    // мы можем взять этот отрезок
                    included.insert(testedSegment);
                    lastIncludedCoord = r;
                }
                ++segmentPointer;
            }

            ll length = included.size();

            if (length > a) {
                // формируем список кандидатов на удаление в правильном порядке
                vector<segment> to_remove(included.size());
                auto p = included.begin();
                for (ll i = 0; i < length; ++i) {
                    to_remove[i] = *p;
                    ++p;
                }
                sort(to_remove.begin(), to_remove.end(), cmpToRemove);
                ll to_remove_count = length - a;
                for (ll i = 0; i < to_remove_count; ++i) {
                    segment s = to_remove[i];
                    segments_set.erase(segments_set.find(s));
                }
            } else {
                ll current_segments_count = segments_set.size();
                if (current_segments_count > n / 2) {
                    // удаляем любые отрезки, не находящиеся в текущей цепочке
                    for (auto seg: segments) {
                        if (segments_set.size() == n / 2) break;
                        segment ss = {{seg.first.second, seg.first.first}, seg.second};
                        if (!included.count(ss) && segments_set.count(ss)) {
                            segments_set.erase(segments_set.find(ss));
                        }
                    }
                }
                break;
            }
        }
        for (auto seg: segments_set) {
            cout << seg.second + 1 << ' ';
        }
        cout << endl;
    }
}