#include <bits/stdc++.h>

using namespace std;
typedef long long ll;
typedef long double ld;

const int INF = 1e9;

struct Meeting {
	int l, r, id;
};

template <typename T>
struct SegmentTree {
	int tree_size;
	T def;
	vector <T> tree;

	SegmentTree (int n, T def): def(def) {
		tree_size=  1;
		while (tree_size < n)
			tree_size <<= 1;

		tree.assign(2 * tree_size, def);
	}

	void update(int v, int tl, int tr, int pos, T value) {
		if (tr - tl == 1) {
			tree[v] = max(tree[v], value);
			return;
		}

		int mid =(tl +tr) / 2;
		if (pos < mid) {
			update(2 * v, tl, mid , pos, value);
		} else {
			update(2 * v + 1, mid,  tr, pos, value);
		}

		tree[v] = max(tree[2 * v], tree[2 * v + 1]);
	}

	void update(int pos, T value) {
		update(1, 0, tree_size, pos, value);
	}

	T query(int v, int tl, int tr, int l, int r) {
		if (tl  >= r || tr <= l)
			return def;

		if (tl >= l && tr <= r)
			return tree[v];

		int mid = (tl + tr)/  2;
		T left = query(2 * v, tl, mid, l,r );
		T right = query(2 * v + 1, mid, tr, l, r);
		return max(left, right);
	}

	T query(int l, int r) {
		return query(1, 0, tree_size, l, r);
	}
};

void solve() {
	int n;
	cin >> n;

	vector <int> to_be_compressed;

	int meeting_id = 1;
	vector <Meeting> meetings(n);
	for (auto &me: meetings) {
		cin >> me.l >> me.r;
		to_be_compressed.push_back(me.l);
		to_be_compressed.push_back(me.r);
		me.id = meeting_id++;
	}

	sort(to_be_compressed.begin(), to_be_compressed.end());
	to_be_compressed.resize(unique(to_be_compressed.begin(), to_be_compressed.end()) - to_be_compressed.begin());

	map <int, int> compressed;
	int nc = to_be_compressed.size();
	for (int i = 0; i < nc; i++)
		compressed[to_be_compressed[i]] = i;

	sort(meetings.begin(), meetings.end(), [&] (auto lhs, auto rhs) {
		return lhs.r < rhs.r;
	});

	auto find_m = [&] () {
		vector <int> dp(n, 1);
		SegmentTree<int> tree(nc, -1);
		for (int i = 0; i < n; i++) {
			dp[i] = max(dp[i], tree.query(0, compressed[meetings[i].l]) + 1);
			tree.update(compressed[meetings[i].r], dp[i]);
		}

		return *max_element(dp.begin(), dp.end());
	};

	int M = find_m();
	#ifdef local
	cout << M << '\n';
	#endif

	if (M % 2 != 0 || n % 2 != 0) {
		cout << "-1\n";
		return;
	}

	vector <vector <pair <int, int>>> dp(n, vector <pair <int, int>> (M / 2 + 1, {-INF, INF}));
	vector <vector <pair <int, int>>> parent(n, vector <pair <int, int>> (M / 2 + 1, {-1, -1}));

	for (int i = 0; i < n; i++) {
		dp[i][1] = {1, -meetings[i].r};
	}

	SegmentTree<pair <pair <int, int>, int>> tree_back(nc, {{-INF, INF}, -1}), tree_now(nc, {{-INF, INF}, -1});
	for (int k = 1; k <= M / 2; k++) {
		for (int i = 0; i < n; i++) {
			auto prev = tree_now.query(compressed[meetings[i].l], nc);
			
			pair <int, int> new_dp = {prev.first.first + 1, prev.first.second};
			if (new_dp > dp[i][k] && prev.second != -1) {
				parent[i][k] = {prev.second, k};
				dp[i][k] = new_dp;
			}

			if (k > 1) {
				auto back = tree_back.query(0, compressed[meetings[i].l]);
				pair <int, int> new_dp = {back.first.first + 1, -meetings[i].r};
				
				if (new_dp > dp[i][k] && back.second != -1) {
					parent[i][k] = {back.second, k - 1};
					dp[i][k] = new_dp;
				}
			}

			if (dp[i][k].first > 0) {
				tree_now.update(compressed[-dp[i][k].second], {dp[i][k], i});
			}

			if (k > 1 && dp[i][k - 1].first > 0) {
				tree_back.update(compressed[-dp[i][k - 1].second], {dp[i][k - 1], i});
			}
		}

		tree_back.tree.assign(2 * tree_back.tree_size, {{-INF, INF}, -1});
		tree_now.tree.assign(2 * tree_now.tree_size, {{-INF, INF}, -1});
	}

	int cur_i = -1;
	for (int i = 0; i < n; i++) {
		if (dp[i][M / 2].first >= n / 2) {
			cur_i = i;
			break;
		}
	}

	assert(cur_i != -1);

	unordered_set <int> seen;

	vector <int> answer;	
	int drop_count = dp[cur_i][M / 2].first - n / 2;

	int cur_j = M / 2;
	while (cur_i != -1) {
		auto [pi, pj] = parent[cur_i][cur_j];
		// cout << cur_i << ' ' << cur_j << endl;

		if (pj == cur_j && drop_count > 0) {
			drop_count--;
		} else if (cur_i != -1) {
			answer.push_back(meetings[cur_i].id);
			seen.insert(meetings[cur_i].id);
		}

		cur_i = pi, cur_j = pj;
	}

	assert(answer.size() == n / 2);

	sort(answer.begin(), answer.end());
	for (int x: answer)
		cout << x << ' ';
	cout << '\n';


	#ifdef local
	auto check = [&] () {
		vector <int> dp(n, 1);
		for (int i = 0; i < n; i++) {
			if (seen.find(meetings[i].id) == seen.end()) continue;
			for (int j = 0; j < i; j++) {
				if (seen.find(meetings[j].id) == seen.end()) continue;
				if (meetings[j].r < meetings[i].l) {
					dp[i] = max(dp[i], dp[j] + 1);
				}
			}
		}

		return *max_element(dp.begin(), dp.end());
	};

	int actual_m = check();
	cout << "actual_m: " <<  actual_m << " expected " << M / 2 << endl;
	assert(actual_m == M / 2);
	#endif
}

signed main() {
	cin.tie(NULL);
	ios_base::sync_with_stdio(false);

	int t;
	cin >> t;

	while (t--)
	solve();
}