#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>

using namespace std;

struct Segment {
    int l, r;
    explicit Segment() = default;
    Segment(int l_, int r_) : l(l_), r(r_) {

    }
    const bool contains(const Segment &other) const {
        return l <= other.l && other.r <= r && (l != other.l || r != other.r);
    }

    const bool operator==(const Segment &other) const {
        return l == other.l && r == other.r;
    }
};


int max_independent(const vector<Segment> &segs) {
    int n = segs.size();
    vector<Segment> new_segs;
    for (int i = 0; i < n; i++) {
        bool inner = false;
        for (int j = 0; j < n && !inner; j++) {
            if (i == j) continue;
            if (segs[i].contains(segs[j]) || (segs[i] == segs[j] && i < j)) {
                inner = true;
            }
        }
        if (!inner) {
            new_segs.push_back(segs[i]);
        }
    }
    sort(new_segs.begin(), new_segs.end(), [](const Segment &s1, const Segment &s2) {
        return s1.l < s2.l;
    });
    int r = 0;
    int ptr = 0;
    int k = new_segs.size();
    int ans = 0;
    while (ptr < k) {
        while (ptr < k && new_segs[ptr].l <= r) {
            ptr++;
        }
        if (ptr != k) {
            r = new_segs[ptr].r;
            ans++;
        }
    }
    return ans;
}

void solve() {
    int n; cin >> n;
    vector<Segment> segs;
    for (int i = 0; i < n; i++) {
        int l, r; cin >> l >> r;
        segs.emplace_back(l, r);
    }
    int m = max_independent(segs);
    // cerr << "MAX INDEPENDENT " << m << endl;
    for (int mask = 0; mask < (1 << n); mask++) {
        if (__builtin_popcount(mask) != n / 2) continue;
        vector<Segment> new_segs;
        for (int bit = 0; bit < n; bit++) {
            if ((mask >> bit) & 1) {
                new_segs.push_back(segs[bit]);
            }
        }
        if (max_independent(new_segs) == m / 2) {
            for (int bit = 0; bit < n; bit++) {
                if ((mask >> bit) & 1) {
                    cout << bit + 1 << ' ';
                }
            }
            cout << endl;
            return;
        }
    }
    assert(false);
}

int main() {
    int t; cin >> t;
    while (t--) {
        solve();
    }
}
