#include <iostream>
#include <vector>
#include <algorithm>
#include <map>

using namespace std;
using ll = long long;
using vi = vector<int>;
using vvi = vector<vi>;
using vvvi = vector<vvi>;

const int INF = 1e9, MAXK = 17;
int used[(1 << MAXK) + 1];
int MOD;

ostream& operator<<(ostream& out, const vi& a) {
    for (int i : a) {
        out << i << ' ';
    }
    return out;
}

istream& operator>>(istream& in, vi& a) {
    for (int& i : a) {
        in >> i;
    }
    return in;
}

int mex(const vi& a) {
    for (int i : a) {
        used[i] = 1;
    }
    int res = 0;
    for (int i = 0; i <= (int)a.size(); ++i) {
        if (!used[i]) {
            res = i;
            break;
        }
    }
    for (int i : a) {
        used[i] = 0;
    }

    return res;
}

vi ultra(const vi& a) {
    vi res(a);
    int m = mex(a) - 1;
    for (int& i : res) {
        i = (i ^ m);
    }
    return res;
}

int sum(int n) {
    int res = 0;
    while (n) {
        res += n % 2;
        n /= 2;
    }
    return res;
}

int my_log(int n) {
    int res = 0;
    while (n > 1) {
        n /= 2;
        ++res;
    }
    return res;
}

vi decode(int mask, const int C) {
    vi res;
    for (int i = 0; i < C; ++i) {
        if (mask & 1) {
            res.push_back(i);
        }
        mask /= 2;
    }
    return res;
}

int encode(const vi& v) {
    int mask = 0;
    for (int i : v) {
        mask ^= (1 << i);
    }
    return mask;
}

int to(int v, const int C) {
    int res = encode(ultra(decode(v, C)));
    if (res < 0 || res >= (1 << C)) {
        cerr << v << '\n';
        abort();
    }
    return res;
}

bool good_cycle(int start, const int C) {
    int v = to(start, C), u;
    bool ok = (mex(decode(start, C)) == mex(decode(v, C)));
    while (v != start) {
        u = to(v, C);
        ok = ok && (mex(decode(v, C)) == mex(decode(u, C)));
        v = u;
    }
    return ok;
}

int dfs(int v, vi& u, map<int, int>& ans, const int C, int p) {
    if (used[v]) {
        if (ans.find(v) == ans.end()) {
            ans[v] = int(good_cycle(v, C) && mex(decode(v, C)) == p);
        }
        return ans[v];
    }

    used[v] = 1;
    ans[v] = dfs(to(v, C), u, ans, C, p);
    return ans[v];
}

bool slow(vi v, int C, int p) {
    for (int i = 0; i < (1 << C); ++i) {
        v = ultra(v);
    }
    int mn = mex(v), mx = mex(v);
    for (int i = 0; i < (1 << C); ++i) {
        v = ultra(v);
        mn = min(mn, mex(v));
        mx = max(mx, mex(v));
    }
    return mn == mx && mn == p;
}

void solve() {
    int k, n, p;
    cin >> k >> n >> p;
    const int C = (1 << k);

    if (p > n || p != (1 << my_log(p))) {
        cout << 0 << '\n';
        return;
    }

    map<int, int> stable;
    int res = 0;
    vi u(1 << C, 0);
    for (int v = 0; v < (1 << C); ++v) {
        if (v % 2 == 1 && sum(v) == n) {
            res += (int)slow(decode(v, C), C, p);
            /*if (!u[v]) {
                dfs(v, u, stable, C, p);
            }
            if (stable[v]) {
                ++res;
            }*/
        }
    }
    cout << res << '\n';
}

void precalc() {
    for (int i = 0; i <= (1 << MAXK); ++i) {
        used[i] = 0;
    }
}

int main() {
    ios::sync_with_stdio(0);
    cin.tie(0);
    precalc();

    cin >> MOD;
    int t;
    cin >> t;

    for (; t; --t) {
        solve();
    }
    return 0;
}
