#include <iostream>
#include <vector>
#include <functional>
#include <set>
#include <array>
#include <cassert>
#include <algorithm>
#include <map>
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/tree_policy.hpp>

using namespace __gnu_pbds;
using namespace std;

#define int long long
#define all(x) (x).begin(), (x).end()
#define sz(x) (int) ((x).size())

const int inf = 1e18;

struct Fenwick {
  vector<int> t;
  bool rev;
  int n;

  Fenwick(int n, bool rev): t(n + 1), rev(rev), n(n) {}

  void upd(int i, int val) {
    if (rev) {
      i = n - i;
    } else {
      i += 1;
    }
    for (; i <= n; i += i & -i) {
      t[i] = max(t[i], val);
    }
  }

  int get(int r) {
    if (rev) {
      r = n - r;
    } else {
      r += 1;
    }
    int res = 0;
    for (; r > 0; r -= r & -r) {
      res = max(res, t[r]);
    }

    return res;
  }
};

struct FenwickST {
  vector<vector<pair<int, int>>> t;
  bool rev;
  int n;

  FenwickST(int n, bool rev): t(n + 1), rev(rev), n(n) {}

  void upd(int i, int val, int kok) {
    if (rev) {
      i = n - i;
    } else {
      i += 1;
    }
    for (; i <= n; i += i & -i) {
      t[i].emplace_back(val, kok);
    }
  }

  void build() {
    for (int i = 1; i <= n; i++) {
      sort(all(t[i]));
      int cur_record = -1;
      vector<pair<int, int>> nt;
      for (int j = sz(t[i]) - 1; j >= 0; j--) {
        if (t[i][j].second > cur_record) {
          nt.push_back(t[i][j]);
          cur_record = t[i][j].second;
        }
      }
      t[i].swap(nt);
    }
  }

  int get(int r, int border) {
    if (rev) {
      r = n - r;
    } else {
      r += 1;
    }
    int res = 0;
    for (; r > 0; r -= r & -r) {
      int id = lower_bound(all(t[r]), make_pair(border, -1ll)) - t[r].begin();
      if (id != sz(t[r])) {
        res = max(res, t[r][id].second);
      }
    }

    return res;
  }
};

void solve() {
  int n;
  cin >> n;
  vector<int> cs;
  vector<array<int, 2>> a(n);
  for (auto &[l, r] : a) {
    cin >> l >> r;
    cs.push_back(l);
    cs.push_back(r);
  }

  sort(all(cs));
  cs.erase(unique(all(cs)), cs.end());
  map<int, int> mp;
  for (int i = 0; i < sz(cs); i++) {
    mp[cs[i]] = i;
  }

  for (auto &[l, r] : a) {
    l = mp[l];
    r = mp[r];
  }

  vector<int> p(n);
  for (int i = 0; i < n; i++) {
    p[i] = i;
  }
  sort(all(p), [&] (const int& i, const int& j) {
    return make_pair(a[i][1], a[i][0]) < make_pair(a[j][1], a[j][0]);
  });

  auto new_a = a;
  for (int i = 0; i < n; i++) {
    new_a[i] = a[p[i]];
  }
  a.swap(new_a);

  vector<int> suf(n);
  Fenwick ft(2 * n + 1, true);
  for (int i = n - 1; i >= 0; i--) {
    suf[i] = 1 + ft.get(a[i][1] + 1);
    ft.upd(a[i][0], suf[i]);
  }

  int rem = n / 2;
  int need = *max_element(all(suf)) / 2;
  vector<int> ban(n);

  FenwickST ft1(n, true);
  for (int i = 0; i < n; i++) {
    ft1.upd(i, a[i][0], suf[i]);
  }
  ft1.build();

  vector<int> cur;
  auto calc = [&] (int l, int r) { // ban[l..r] = 1
    int cur_r = (cur.empty() ? -1 : a[cur.back()][1]);
    return sz(cur) + ft1.get(r + 1, cur_r + 1);
  };

  bool was = false;
  for (int i = 0; i + rem <= n; i++) {
    int L = i, R = i + rem - 1;
    if (calc(L, R) <= need) {
      rem = 0;
      while (calc(L, R) < need) {
        int cur_r = (cur.empty() ? -1 : a[cur.back()][1]);
        if (a[L][0] > cur_r) {
          cur.push_back(L);
        }
        L++;
        rem++;
      }
      for (int j = L; j <= R; j++) {
        ban[j] = 1;
      }
      break;
    }
    int cur_r = (cur.empty() ? -1 : a[cur.back()][1]);
    if (a[i][0] > cur_r) {
      cur.push_back(i);
    }
  }

  vector<int> in(n);
  int cur_r = -1;
  for (int i = 0; i < n; i++) {
    if (ban[i]) {
      continue;
    }
    auto [l, r] = a[i];
    if (l > cur_r) {
      cur_r = r;
      in[i] = 1;
    }
  }

  for (int i = 0; i < n; i++) {
    if (!ban[i] && !in[i] && rem > 0) {
      rem -= 1;
      ban[i] = 1;
    }
    if (!ban[i]) {
      cout << p[i] + 1 << ' ';
    }
  }

  cout << '\n';

  assert(rem == 0);
}

int32_t main() {
#ifdef LOCAL
  freopen("input.txt", "r", stdin);
#endif
  ios_base::sync_with_stdio(false);
  cin.tie(nullptr);
  int tc;
  cin >> tc;
  while (tc --> 0) solve();
  return 0;
}