#include <iostream>
#include <vector>
#include <algorithm>
#include <deque>

using namespace std;

typedef long long ll;

//const int MAX = (1 << 30);
const int MAX = 32;

class SegmentTree {
private:
	struct Node {
		int l = -1, r = -1;
		int mx = 0, idx = 0;
		Node() {}
	};
	vector<Node> t;

	void push(int i) {
		if (t[i].l == -1) {
			t[i].l = t.size();
			t.push_back(Node());
			t[i].r = t.size();
			t.push_back(Node());
		}
	}

	void upd(int i, int l, int r, int q, int x, int idx) {
		push(i);
		if (q < l || q >= r)
			return;
		if (x > t[i].mx) {
			t[i].mx = x;
			t[i].idx = idx;
		}
		if (r - l == 1)
			return;
		int m = (l + r) / 2;
		upd(t[i].l, l, m, q, x, idx);
		upd(t[i].r, m, r, q, x, idx);
	}
	pair<int, int> get(int i, int l, int r, int ql, int qr) {
		push(i);
		if (qr <= l || r <= ql)
			return { -1, -1 };
		if (ql <= l && r <= qr)
			return { t[i].mx, t[i].idx };
		int m = (l + r) / 2;
		auto f1 = get(t[i].l, l, m, ql, qr);
		auto f2 = get(t[i].r, m, r, ql, qr);
		if (f1.first > f2.first)
			return f1;
		return f2;
	}

public:
	SegmentTree() {
		t.push_back(Node());
	}
	void upd(int q, int x, int idx) {
		upd(0, 0, MAX, q, x, idx);
	}
	// [l ; r)
	pair<int, int> get(int ql, int qr) {
		return get(0, 0, MAX, ql, qr);
	}
};

struct Segment {
	int l = 0, r = 0;
	int idx = 0;

	bool operator <(const Segment& other) const {
		if (l == other.l)
			return r < other.r;
		return l < other.l;
	}

	Segment() {}
};


int dynamic(vector<Segment>& a, vector<int>& p, vector<int>& dp) {
	SegmentTree t;
	for (int i = 0; i < a.size(); ++i) {
		auto res = t.get(0, a[i].l + 1);
		t.upd(a[i].r + 1, res.first + 1, i);
		p[a[i].idx] = res.second;
		dp[a[i].idx] = res.first + 1;
	}
	return t.get(0, MAX).second;
}

bool cmp(const Segment& a, const Segment& b) {
	if (a.r == b.r)
		return a.l < b.l;
	return a.r < b.r;
}

bool cmp2(const deque<int>& a, const deque<int>& b) {
	return a.size() < b.size();
}

void solve() {
	int n;
	cin >> n;
	vector<Segment> a(n);
	for (int i = 0; i < n; ++i) {
		cin >> a[i].l >> a[i].r;
		a[i].idx = i;
	}
	sort(a.begin(), a.end());


	vector<int> dp(n), p(n, -1);
	int f = dynamic(a, p, dp);
	int m = dp[f];


	sort(a.begin(), a.end(), cmp);
	vector<bool> in_ns(n, false);
	deque<deque<int>> ns;
	int mx = 0;
	for (int i = 0; i < n; ++i) {
		int cur = dp[a[i].idx];
		if (cur == mx) {
			ns.back().push_back(a[i].idx);
		} else if (cur > mx) {
			ns.push_back({ a[i].idx });
			mx = cur;
		}
		in_ns[ns.back().back()] = true;
	}
	vector<int> free;
	for (int i = 0; i < n; ++i) {
		if (!in_ns[i])
			free.push_back(i);
	}

	sort(ns.begin(), ns.end(), cmp2);

	/*
	cout << "ns:\n";
	for (int i = 0; i < ns.size(); ++i) {
		cout << i + 1 << ": ";
		for (auto x : ns[i]) {
			cout << x + 1 << " ";
		}
		cout << "\n";
	}
	cout << "\n";
	*/

	vector<bool> deleted(n, false);

	int i = ns.size() - 1;

	for (int k = 0; k < n / 2; ++k) {
		if (ns.size() > m / 2) {
			deleted[ns.front()[0]] = true;
			ns.front().pop_front();
			if (ns.front().empty()) {
				ns.pop_front();
				--i;
			}
		} else {
			if (!free.empty()) {
				deleted[free.back()] = true;
				free.pop_back();
			} else {
				while (ns[i].size() == 1)
					--i;
				deleted[ns[i].back()] = true;
				ns[i].pop_back();
			}
		}
	}

	for (int i = 0; i < n; ++i) {
		if (deleted[i]) continue;
		cout << i + 1 << " ";
	}
	cout << "\n";
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	int t;
	cin >> t;
	while (t--) {
		solve();
	}
}
