#include <iostream>
#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;

ll INF = 1e18;
ll MOD = 1e9 + 7;
ld EPS = 1e-9;

struct DSU {
    vector<ll> p, sz;

    explicit DSU(ll n) {
        p.assign(n, 0);
        for (ll i = 0; i < n; i++) p[i] = i;
        sz.assign(n, 1);
    }

    ll get(ll v) {
        if (p[v] == v) return v;
        return p[v] = get(p[v]);
    }

    void merge(ll a, ll b) {
        a = get(a), b = get(b);
        if (a == b) return;

        if (sz[a] < sz[b]) swap(a, b);

        sz[a] += sz[b];
        p[b] = a;
    }
};

struct SegmentTree {
    struct Node {
        ll x, ind;
    };

    Node NEUTRAL = {0, 0};
    ll n;

    vector<Node> p;

    explicit SegmentTree(ll n): n(n) {
        p.assign(4 * n, NEUTRAL);
        build(0, 0, n);
    }

    Node merge(Node p1, Node p2) {
        if (p2.x >= p1.x) return p2;
        return p1;
    }

    void build(ll i, ll l, ll r) {
        if (l + 1 == r) {
            p[i] = {0, l};
        } else {
            ll m = (l + r) / 2;
            build(2 * i + 1, l, m);
            build(2 * i + 2, m, r);

            p[i] = merge(p[2 * i + 1], p[2 * i + 2]);
        }
    }

    Node _get(ll i, ll l, ll r, ll q_l, ll q_r) {
        if (r <= q_l || q_r <= l) return NEUTRAL;
        if (q_l <= l && r <= q_r) return p[i];

        ll m = (l + r) / 2;
        return merge(_get(2 * i + 1, l, m, q_l, q_r), _get(2 * i + 2, m, r, q_l, q_r));
    }

     void _set(ll i, ll l, ll r, ll q_i, ll q_x) {
        if (l + 1 == r) {
            p[i] = {q_x, l};
        } else {
            ll m = (l + r) / 2;
            if (q_i < m)
                _set(2 * i + 1, l, m, q_i, q_x);
            else
                _set(2 * i + 2, m, r, q_i, q_x);

            p[i] = merge(p[2 * i + 1], p[2 * i + 2]);
        }
    }

    Node get(ll l, ll r) {
        return _get(0, 0, n, l, r);
    }

    void set(ll i, ll x) {
        _set(0, 0, n, i, x);
    }
};

int main() {
#ifdef LOCAL
    freopen("inp.txt", "r", stdin);
    freopen("out.txt", "w", stdout);

    clock_t timer = clock();
#else
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    cout.precision(64);
    cout << fixed;
#endif

    ll a, t;
    cin >> a >> t;

    if (a == 1) {
        while (t--) {
            ll n, k;
            cin >> n >> k;
            vector<bool> w(n);
            vector<ll> p(k);
            for (ll i = 0; i < k; i++) {
                cin >> p[i];
                p[i]--;
            }
            for (ll i = 0; i < k; i++) w[p[i]] = true;

            SegmentTree st(n);
            for (ll i = 0; i < n; i++)
                if (!w[i])
                    st.set(i, 1);

            vector<bool> bAns(n);

            for (ll i = 0; i < n; i++) {
                if (w[i]) {
                    auto g1 = st.get(0, i);
                    if (g1.x == 1) {
                        bAns[g1.ind] = true;
                        st.set(g1.ind, 0);
                    } else {
                        auto g2 = st.get(0, n);
                        bAns[g2.ind] = true;
                        st.set(g2.ind, 0);
                    }
                }
            }

            for (ll i = 0; i < n; i++)
                if (bAns[i])
                    cout << i + 1 << " ";
            cout << "\n";
        }
    } else {
        while (t--) {
            ll n, k;
            cin >> n >> k;
            vector<bool> w(n);
            vector<ll> p(k);
            for (ll i = 0; i < k; i++) {
                cin >> p[i];
                p[i]--;
            }
            for (ll i = 0; i < k; i++) w[p[i]] = true;

            if (2 * k == n) {
                for (ll i = 0; i < n; i++)
                    if (!w[i])
                        cout << i + 1 << " ";
                cout << "\n";
                continue;
            }

            ll mn = INF;
            for (ll i = 0; i < n; i++)
                if (w[i])
                    mn = min(mn, i);

            ll x = mn % n;
            ll b = 0;
            vector<ll> ans;
            for (ll i = 0; i < n; i++) {
                if (w[(i+x) % n]) {
                    b++;
                } else if (b > 0) {
                    ans.push_back((i + x) % n + 1);
                    b--;
                }
            }

            sort(ans.begin(), ans.end());
            for (ll q : ans) cout << q << " ";
            cout << "\n";
        }
    }

#ifdef LOCAL
    cout << "\nExecution time: " << (ld)(clock() - timer) / CLOCKS_PER_SEC;
#endif
}